# Standard Library
from typing import List, Optional

# 1st Party Libraries
import open_exchange
from open_exchange.types.data import property_details_fetch_params, property_details_response

# get API KEY from environment variable OPEN_EXCHANGE_API_KEY
client = open_exchange.OpenExchangeClient()

addresses: List[property_details_fetch_params.Address] = [
    {
        "street": "19423 Garden Gate Ct",
        "city": "Houston",
        "state": "TX",
        "postal_code": "77073",
        "token": "client-provided-token-0",
    },
    {
        "street": "14745 Country Club Dr",
        "city": "Beaumont",
        "state": "TX",
        "postal_code": "77705",
        "token": "client-provided-token-1",
    },
    {
        "street": "1808 Otwell Dr",
        "city": "Haslet",
        "state": "TX",
        "postal_code": "76052",
        "token": "client-provided-token-2",
    },
    {
        "street": "46 Crestbrook Ln",
        "city": "Dallas",
        "state": "GA",
        "postal_code": "30157",
        "token": "client-provided-token-3",
    },
    {
        "street": "1952 Lariat Dr",
        "city": "Justin",
        "state": "TX",
        "postal_code": "76247",
        "token": "client-provided-token-4",
    },
    {
        "street": "3841 Quill Ct",
        "city": "Gastonia",
        "state": "NC",
        "postal_code": "28056",
        "token": "client-provided-token-5",
    },
    {
        "street": "3409 Chardmore Dr",
        "city": "Matthews",
        "state": "NC",
        "postal_code": "28105",
        "token": "client-provided-token-6",
    },
    {
        "street": "1629 Megan Creek Dr",
        "city": "Little Elm",
        "state": "TX",
        "postal_code": "75068",
        "token": "client-provided-token-7",
    },
    {
        "street": "4111 Magliana Ln",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77449",
        "token": "client-provided-token-8",
    },
    {
        "street": "8108 Nube Medina",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78252",
        "token": "client-provided-token-9",
    },
    {
        "street": "20426 Drakewood Dr",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77449",
        "token": "client-provided-token-10",
    },
    {
        "street": "2105 Broad Plum Ln",
        "city": "Indian Trail",
        "state": "NC",
        "postal_code": "28079",
        "token": "client-provided-token-11",
    },
    {
        "street": "4825 Mocha Ln",
        "city": "Raleigh",
        "state": "NC",
        "postal_code": "27616",
        "token": "client-provided-token-12",
    },
    {
        "street": "526 Perch Mdw",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-13",
    },
    {
        "street": "10403 McClintock Dr",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-14",
    },
    {
        "street": "10639 Vinateros Dr",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-15",
    },
    {
        "street": "3770 Lilly Brook Dr",
        "city": "Loganville",
        "state": "GA",
        "postal_code": "30052",
        "token": "client-provided-token-16",
    },
    {
        "street": "1132 Brookstone Estates Dr",
        "city": "Loganville",
        "state": "GA",
        "postal_code": "30052",
        "token": "client-provided-token-17",
    },
    {
        "street": "4885 Montcalm Dr SW",
        "city": "Atlanta",
        "state": "GA",
        "postal_code": "30331",
        "token": "client-provided-token-18",
    },
    {
        "street": "360 Dry Canyon Way",
        "city": "Haslet",
        "state": "TX",
        "postal_code": "76052",
        "token": "client-provided-token-19",
    },
    {
        "street": "5219 Addison St",
        "city": "Flowery Branch",
        "state": "GA",
        "postal_code": "30542",
        "token": "client-provided-token-20",
    },
    {
        "street": "1238 Cabots Dr",
        "city": "Auburn",
        "state": "GA",
        "postal_code": "30011",
        "token": "client-provided-token-21",
    },
    {
        "street": "14765 Country Club Dr",
        "city": "Beaumont",
        "state": "TX",
        "postal_code": "77705",
        "token": "client-provided-token-22",
    },
    {
        "street": "6020 Spring Ranch Dr",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76179",
        "token": "client-provided-token-23",
    },
    {
        "street": "7602 Wynstone Ridge Cir",
        "city": "Huntersville",
        "state": "NC",
        "postal_code": "28078",
        "token": "client-provided-token-24",
    },
    {
        "street": "5018 Ingomar Way",
        "city": "Houston",
        "state": "TX",
        "postal_code": "77053",
        "token": "client-provided-token-25",
    },
    {
        "street": "2612 Clarks Mill Ln",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76123",
        "token": "client-provided-token-26",
    },
    {
        "street": "790 Waller Dr",
        "city": "Fate",
        "state": "TX",
        "postal_code": "75087",
        "token": "client-provided-token-27",
    },
    {
        "street": "409 Kendall Ln",
        "city": "McDonough",
        "state": "GA",
        "postal_code": "30253",
        "token": "client-provided-token-28",
    },
    {
        "street": "5339 Devils Rdg",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-29",
    },
    {
        "street": "13044 Ferguson Forest Dr",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28273",
        "token": "client-provided-token-30",
    },
    {
        "street": "3026 Hemingway Dr",
        "city": "Montgomery",
        "state": "TX",
        "postal_code": "77356",
        "token": "client-provided-token-31",
    },
    {
        "street": "13010 Rosemary Cv",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-32",
    },
    {
        "street": "5218 Eagleton Dr",
        "city": "Rosenberg",
        "state": "TX",
        "postal_code": "77469",
        "token": "client-provided-token-33",
    },
    {
        "street": "145 Road 5102 F",
        "city": "Cleveland",
        "state": "TX",
        "postal_code": "77327",
        "token": "client-provided-token-34",
    },
    {
        "street": "10427 Midsummer Mdw",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-35",
    },
    {
        "street": "6203 Higbee Ml",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78247",
        "token": "client-provided-token-36",
    },
    {
        "street": "25602 Roy Rogers Rd",
        "city": "Splendora",
        "state": "TX",
        "postal_code": "77372",
        "token": "client-provided-token-37",
    },
    {
        "street": "12222 Pompton Dr",
        "city": "Houston",
        "state": "TX",
        "postal_code": "77089",
        "token": "client-provided-token-38",
    },
    {
        "street": "8549 N 32nd Dr",
        "city": "Phoenix",
        "state": "AZ",
        "postal_code": "85051",
        "token": "client-provided-token-39",
    },
    {
        "street": "126 Capri Ct",
        "city": "Lexington",
        "state": "NC",
        "postal_code": "27295",
        "token": "client-provided-token-40",
    },
    {
        "street": "1623 Amelia Ct",
        "city": "Hampton",
        "state": "GA",
        "postal_code": "30228",
        "token": "client-provided-token-41",
    },
    {
        "street": "13704 Stringfellow Ln",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28278",
        "token": "client-provided-token-42",
    },
    {
        "street": "5027 Cambridge Ln",
        "city": "Villa Rica",
        "state": "GA",
        "postal_code": "30180",
        "token": "client-provided-token-43",
    },
    {
        "street": "72 Hidden Pines Cir",
        "city": "Pendergrass",
        "state": "GA",
        "postal_code": "30567",
        "token": "client-provided-token-44",
    },
    {
        "street": "105 Tanner Dr",
        "city": "Dallas",
        "state": "GA",
        "postal_code": "30157",
        "token": "client-provided-token-45",
    },
    {
        "street": "7850 Rolling Meadows Ln",
        "city": "Huntersville",
        "state": "NC",
        "postal_code": "28078",
        "token": "client-provided-token-46",
    },
    {
        "street": "111 Norwood Ct N",
        "city": "Mebane",
        "state": "NC",
        "postal_code": "27302",
        "token": "client-provided-token-47",
    },
    {
        "street": "403 Middlebrooke St",
        "city": "Canton",
        "state": "GA",
        "postal_code": "30115",
        "token": "client-provided-token-48",
    },
    {
        "street": "8330 W Kingman St",
        "city": "Tolleson",
        "state": "AZ",
        "postal_code": "85353",
        "token": "client-provided-token-49",
    },
    {
        "street": "221 Buckskin Dr",
        "city": "Waxahachie",
        "state": "TX",
        "postal_code": "75167",
        "token": "client-provided-token-50",
    },
    {
        "street": "8918 Comstock Ct",
        "city": "Locust",
        "state": "NC",
        "postal_code": "28097",
        "token": "client-provided-token-51",
    },
    {
        "street": "23803 N Desert Agave St",
        "city": "Florence",
        "state": "AZ",
        "postal_code": "85132",
        "token": "client-provided-token-52",
    },
    {
        "street": "13121 Rustic Cir",
        "city": "Balch Springs",
        "state": "TX",
        "postal_code": "75180",
        "token": "client-provided-token-53",
    },
    {
        "street": "67 Oakbrook Dr SW",
        "city": "Cartersville",
        "state": "GA",
        "postal_code": "30120",
        "token": "client-provided-token-54",
    },
    {
        "street": "1736 S 236th Dr",
        "city": "Buckeye",
        "state": "AZ",
        "postal_code": "85326",
        "token": "client-provided-token-55",
    },
    {
        "street": "237 Prescott Dr",
        "city": "Acworth",
        "state": "GA",
        "postal_code": "30101",
        "token": "client-provided-token-56",
    },
    {
        "street": "139 Rosedale Cir",
        "city": "Winston Salem",
        "state": "NC",
        "postal_code": "27106",
        "token": "client-provided-token-57",
    },
    {
        "street": "1146 Cool Springs Dr NW",
        "city": "Kennesaw",
        "state": "GA",
        "postal_code": "30144",
        "token": "client-provided-token-58",
    },
    {
        "street": "189 Shad Boat Ln",
        "city": "Clayton",
        "state": "NC",
        "postal_code": "27520",
        "token": "client-provided-token-59",
    },
    {
        "street": "1225 Chapman Dr",
        "city": "Mesquite",
        "state": "TX",
        "postal_code": "75149",
        "token": "client-provided-token-60",
    },
]

# get property details for a iterable of addresses
ordered_tokens = [address["token"] for address in addresses]
for result, expected_token in zip(
    client.data.property_details.fetch(addresses=addresses), ordered_tokens
):  # type: (property_details_response.Result, Optional[str])
    assert result.token == expected_token

    if result.property_details:
        print("Subject property details:", result.property_details)
    else:
        print("No property details available for this address.")
