# Standard Library
from typing import List, Optional

# 1st Party Libraries
import open_exchange
from open_exchange.types.data import property_values_fetch_params, property_values_response

# get API KEY from environment variable OPEN_EXCHANGE_API_KEY
client = open_exchange.OpenExchangeClient()

addresses: List[property_values_fetch_params.Address] = [
    {
        "street": "11905 Rustling Oaks Dr",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76036",
        "token": "client-provided-token-0",
    },
    {
        "street": "7214 Keechi Pl",
        "city": "Mont Belvieu",
        "state": "TX",
        "postal_code": "77523",
        "token": "client-provided-token-1",
    },
    {
        "street": "28907 Ashbrook Ln",
        "city": "Magnolia",
        "state": "TX",
        "postal_code": "77355",
        "token": "client-provided-token-2",
    },
    {
        "street": "1572 Panola Rd",
        "city": "Ellenwood",
        "state": "GA",
        "postal_code": "30294",
        "token": "client-provided-token-3",
    },
    {
        "street": "24562 Lorenzo Glaze Trl",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77493",
        "token": "client-provided-token-4",
    },
    {
        "street": "1169 Crestview Dr",
        "city": "Hutchins",
        "state": "TX",
        "postal_code": "75141",
        "token": "client-provided-token-5",
    },
    {
        "street": "67 Oakbrook Dr SW",
        "city": "Cartersville",
        "state": "GA",
        "postal_code": "30120",
        "token": "client-provided-token-6",
    },
    {
        "street": "13044 Ferguson Forest Dr",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28273",
        "token": "client-provided-token-7",
    },
    {
        "street": "1020 E Denim Trl",
        "city": "San Tan Valley",
        "state": "AZ",
        "postal_code": "85143",
        "token": "client-provided-token-8",
    },
    {
        "street": "4419 Abaco Ln",
        "city": "Houston",
        "state": "TX",
        "postal_code": "77045",
        "token": "client-provided-token-9",
    },
    {
        "street": "1952 Lariat Dr",
        "city": "Justin",
        "state": "TX",
        "postal_code": "76247",
        "token": "client-provided-token-10",
    },
    {
        "street": "4111 Magliana Ln",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77449",
        "token": "client-provided-token-11",
    },
    {
        "street": "5380 Barberry Ave",
        "city": "Oakwood",
        "state": "GA",
        "postal_code": "30566",
        "token": "client-provided-token-12",
    },
    {
        "street": "8549 N 32nd Dr",
        "city": "Phoenix",
        "state": "AZ",
        "postal_code": "85051",
        "token": "client-provided-token-13",
    },
    {
        "street": "4142 Woodland Park Dr SW",
        "city": "Atlanta",
        "state": "GA",
        "postal_code": "30331",
        "token": "client-provided-token-14",
    },
    {
        "street": "526 Perch Mdw",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-15",
    },
    {
        "street": "4825 Mocha Ln",
        "city": "Raleigh",
        "state": "NC",
        "postal_code": "27616",
        "token": "client-provided-token-16",
    },
    {
        "street": "7843 Spencer Brook Dr",
        "city": "Summerfield",
        "state": "NC",
        "postal_code": "27358",
        "token": "client-provided-token-17",
    },
    {
        "street": "2234 Sunset Blvd",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28269",
        "token": "client-provided-token-18",
    },
    {
        "street": "3770 Lilly Brook Dr",
        "city": "Loganville",
        "state": "GA",
        "postal_code": "30052",
        "token": "client-provided-token-19",
    },
    {
        "street": "15513 Gray Catbird",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-20",
    },
    {
        "street": "1714 Prism Pl",
        "city": "Kannapolis",
        "state": "NC",
        "postal_code": "28083",
        "token": "client-provided-token-21",
    },
    {
        "street": "3814 Majestic Ln SW",
        "city": "Marietta",
        "state": "GA",
        "postal_code": "30060",
        "token": "client-provided-token-22",
    },
    {
        "street": "1808 Otwell Dr",
        "city": "Haslet",
        "state": "TX",
        "postal_code": "76052",
        "token": "client-provided-token-23",
    },
    {
        "street": "8617 Barrister Way",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28216",
        "token": "client-provided-token-24",
    },
    {
        "street": "111 Norwood Ct N",
        "city": "Mebane",
        "state": "NC",
        "postal_code": "27302",
        "token": "client-provided-token-25",
    },
    {
        "street": "3841 Quill Ct",
        "city": "Gastonia",
        "state": "NC",
        "postal_code": "28056",
        "token": "client-provided-token-26",
    },
    {
        "street": "130 Fir Dr",
        "city": "Winston Salem",
        "state": "NC",
        "postal_code": "27107",
        "token": "client-provided-token-27",
    },
    {
        "street": "3122 Baywood Ct",
        "city": "Conyers",
        "state": "GA",
        "postal_code": "30013",
        "token": "client-provided-token-28",
    },
    {
        "street": "4450 Asbury Place Dr",
        "city": "Clemmons",
        "state": "NC",
        "postal_code": "27012",
        "token": "client-provided-token-29",
    },
    {
        "street": "459 Fernwood Cir",
        "city": "Statham",
        "state": "GA",
        "postal_code": "30666",
        "token": "client-provided-token-30",
    },
    {
        "street": "268 Morning Dew Dr",
        "city": "Concord",
        "state": "NC",
        "postal_code": "28025",
        "token": "client-provided-token-31",
    },
    {
        "street": "90 Cedar Creek Dr",
        "city": "Covington",
        "state": "GA",
        "postal_code": "30014",
        "token": "client-provided-token-32",
    },
    {
        "street": "3025 Jodeco Dr",
        "city": "Jonesboro",
        "state": "GA",
        "postal_code": "30236",
        "token": "client-provided-token-33",
    },
    {
        "street": "6515 Guard Hill Dr",
        "city": "Raleigh",
        "state": "NC",
        "postal_code": "27610",
        "token": "client-provided-token-34",
    },
    {
        "street": "221 Buckskin Dr",
        "city": "Waxahachie",
        "state": "TX",
        "postal_code": "75167",
        "token": "client-provided-token-35",
    },
    {
        "street": "11126 Lulu Ln",
        "city": "Willis",
        "state": "TX",
        "postal_code": "77318",
        "token": "client-provided-token-36",
    },
    {
        "street": "937 Cassidy Dr",
        "city": "Gastonia",
        "state": "NC",
        "postal_code": "28054",
        "token": "client-provided-token-37",
    },
    {
        "street": "1414 Pueblo",
        "city": "Denver",
        "state": "NC",
        "postal_code": "28037",
        "token": "client-provided-token-38",
    },
    {
        "street": "10219 Devon Wheel St",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78254",
        "token": "client-provided-token-39",
    },
    {
        "street": "25602 Roy Rogers Rd",
        "city": "Splendora",
        "state": "TX",
        "postal_code": "77372",
        "token": "client-provided-token-40",
    },
    {
        "street": "6215 Arcadia Sound Ln",
        "city": "Porter",
        "state": "TX",
        "postal_code": "77365",
        "token": "client-provided-token-41",
    },
    {
        "street": "6747 Arid Way",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78252",
        "token": "client-provided-token-42",
    },
    {
        "street": "14755 Country Club Dr",
        "city": "Beaumont",
        "state": "TX",
        "postal_code": "77705",
        "token": "client-provided-token-43",
    },
    {
        "street": "4885 Montcalm Dr SW",
        "city": "Atlanta",
        "state": "GA",
        "postal_code": "30331",
        "token": "client-provided-token-44",
    },
    {
        "street": "14711 Harlequin Duck",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-45",
    },
    {
        "street": "245 Cypress Dr",
        "city": "Covington",
        "state": "GA",
        "postal_code": "30016",
        "token": "client-provided-token-46",
    },
    {
        "street": "105 Tanner Dr",
        "city": "Dallas",
        "state": "GA",
        "postal_code": "30157",
        "token": "client-provided-token-47",
    },
    {
        "street": "409 Kendall Ln",
        "city": "McDonough",
        "state": "GA",
        "postal_code": "30253",
        "token": "client-provided-token-48",
    },
    {
        "street": "8311 Mountainview Dr",
        "city": "Dallas",
        "state": "TX",
        "postal_code": "75249",
        "token": "client-provided-token-49",
    },
    {
        "street": "6020 Spring Ranch Dr",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76179",
        "token": "client-provided-token-50",
    },
    {
        "street": "148 Thorntree Pass",
        "city": "Powder Springs",
        "state": "GA",
        "postal_code": "30127",
        "token": "client-provided-token-51",
    },
    {
        "street": "6203 Higbee Ml",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78247",
        "token": "client-provided-token-52",
    },
    {
        "street": "2612 Clarks Mill Ln",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76123",
        "token": "client-provided-token-53",
    },
    {
        "street": "10427 Midsummer Mdw",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-54",
    },
    {
        "street": "237 Prescott Dr",
        "city": "Acworth",
        "state": "GA",
        "postal_code": "30101",
        "token": "client-provided-token-55",
    },
    {
        "street": "1027 Verde Trails Dr",
        "city": "Houston",
        "state": "TX",
        "postal_code": "77073",
        "token": "client-provided-token-56",
    },
    {
        "street": "331 Estelle Dr",
        "city": "Lexington",
        "state": "NC",
        "postal_code": "27295",
        "token": "client-provided-token-57",
    },
    {
        "street": "14421 Cloudview Way",
        "city": "Haslet",
        "state": "TX",
        "postal_code": "76052",
        "token": "client-provided-token-58",
    },
    {
        "street": "14785 Country Club Dr",
        "city": "Beaumont",
        "state": "TX",
        "postal_code": "77705",
        "token": "client-provided-token-59",
    },
]

# get property values for a iterable of addresses
ordered_tokens = [address["token"] for address in addresses]
for result, expected_token in zip(
    client.data.property_values.fetch(addresses=addresses), ordered_tokens
):  # type: (property_values_response.Result, Optional[str])
    assert result.token == expected_token

    print("Token:", result.token)
    if result.property_value:
        print("Property value low:", result.property_value.value_low)
        print("Property value:", result.property_value.value)
        print("Property value high:", result.property_value.value_high)
    else:
        print("No property value available for this address")
