# Standard Library
from typing import List, Optional

# 1st Party Libraries
import open_exchange
from open_exchange.types.data import rent_estimates_fetch_params, rent_estimates_response

# get API KEY from environment variable OPEN_EXCHANGE_API_KEY
client = open_exchange.OpenExchangeClient()

addresses: List[rent_estimates_fetch_params.Address] = [
    {
        "street": "609 Turtle Dove Dr",
        "city": "Sealy",
        "state": "TX",
        "postal_code": "77474",
        "token": "client-provided-token-0",
    },
    {
        "street": "525 Vernon Ct",
        "city": "Kernersville",
        "state": "NC",
        "postal_code": "27284",
        "token": "client-provided-token-1",
    },
    {
        "street": "634 Canvas Ct",
        "city": "Lancaster",
        "state": "TX",
        "postal_code": "75146",
        "token": "client-provided-token-2",
    },
    {
        "street": "7843 Spencer Brook Dr",
        "city": "Summerfield",
        "state": "NC",
        "postal_code": "27358",
        "token": "client-provided-token-3",
    },
    {
        "street": "189 Shad Boat Ln",
        "city": "Clayton",
        "state": "NC",
        "postal_code": "27520",
        "token": "client-provided-token-4",
    },
    {
        "street": "2227 Bristol Bend Ln",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77450",
        "token": "client-provided-token-5",
    },
    {
        "street": "2977 Jenkins Dr",
        "city": "Snellville",
        "state": "GA",
        "postal_code": "30078",
        "token": "client-provided-token-6",
    },
    {
        "street": "6020 Spring Ranch Dr",
        "city": "Fort Worth",
        "state": "TX",
        "postal_code": "76179",
        "token": "client-provided-token-7",
    },
    {
        "street": "13010 Rosemary Cv",
        "city": "Converse",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-8",
    },
    {
        "street": "12205 Folkston Dr",
        "city": "Huntersville",
        "state": "NC",
        "postal_code": "28078",
        "token": "client-provided-token-9",
    },
    {
        "street": "1623 Amelia Ct",
        "city": "Hampton",
        "state": "GA",
        "postal_code": "30228",
        "token": "client-provided-token-10",
    },
    {
        "street": "2234 Sunset Blvd",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28269",
        "token": "client-provided-token-11",
    },
    {
        "street": "526 Perch Mdw",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-12",
    },
    {
        "street": "5342 Colonial Garden Dr",
        "city": "Huntersville",
        "state": "NC",
        "postal_code": "28078",
        "token": "client-provided-token-13",
    },
    {
        "street": "945 S Willhaven Dr",
        "city": "Fuquay Varina",
        "state": "NC",
        "postal_code": "27526",
        "token": "client-provided-token-14",
    },
    {
        "street": "8311 Mountainview Dr",
        "city": "Dallas",
        "state": "TX",
        "postal_code": "75249",
        "token": "client-provided-token-15",
    },
    {
        "street": "221 Buckskin Dr",
        "city": "Waxahachie",
        "state": "TX",
        "postal_code": "75167",
        "token": "client-provided-token-16",
    },
    {
        "street": "4422 Brook Shadow Dr",
        "city": "Kingwood",
        "state": "TX",
        "postal_code": "77345",
        "token": "client-provided-token-17",
    },
    {
        "street": "3814 Majestic Ln SW",
        "city": "Marietta",
        "state": "GA",
        "postal_code": "30060",
        "token": "client-provided-token-18",
    },
    {
        "street": "2159 Burroughs Ave SE",
        "city": "Atlanta",
        "state": "GA",
        "postal_code": "30315",
        "token": "client-provided-token-19",
    },
    {
        "street": "6747 Arid Way",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78252",
        "token": "client-provided-token-20",
    },
    {
        "street": "1836 Kittredge Way",
        "city": "Justin",
        "state": "TX",
        "postal_code": "76247",
        "token": "client-provided-token-21",
    },
    {
        "street": "105 Tanner Dr",
        "city": "Dallas",
        "state": "GA",
        "postal_code": "30157",
        "token": "client-provided-token-22",
    },
    {
        "street": "6215 Arcadia Sound Ln",
        "city": "Porter",
        "state": "TX",
        "postal_code": "77365",
        "token": "client-provided-token-23",
    },
    {
        "street": "3617 Epperly Ct",
        "city": "Raleigh",
        "state": "NC",
        "postal_code": "27616",
        "token": "client-provided-token-24",
    },
    {
        "street": "409 Kendall Ln",
        "city": "McDonough",
        "state": "GA",
        "postal_code": "30253",
        "token": "client-provided-token-25",
    },
    {
        "street": "241 Bear Oak Dr",
        "city": "Smithfield",
        "state": "NC",
        "postal_code": "27577",
        "token": "client-provided-token-26",
    },
    {
        "street": "790 Waller Dr",
        "city": "Fate",
        "state": "TX",
        "postal_code": "75087",
        "token": "client-provided-token-27",
    },
    {
        "street": "237 Prescott Dr",
        "city": "Acworth",
        "state": "GA",
        "postal_code": "30101",
        "token": "client-provided-token-28",
    },
    {
        "street": "111 Norwood Ct N",
        "city": "Mebane",
        "state": "NC",
        "postal_code": "27302",
        "token": "client-provided-token-29",
    },
    {
        "street": "8952 Hickman Park",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78254",
        "token": "client-provided-token-30",
    },
    {
        "street": "3742 Otello Pl",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77493",
        "token": "client-provided-token-31",
    },
    {
        "street": "7243 Foxtail Meadow Ct",
        "city": "Humble",
        "state": "TX",
        "postal_code": "77338",
        "token": "client-provided-token-32",
    },
    {
        "street": "1146 Cool Springs Dr NW",
        "city": "Kennesaw",
        "state": "GA",
        "postal_code": "30144",
        "token": "client-provided-token-33",
    },
    {
        "street": "268 Morning Dew Dr",
        "city": "Concord",
        "state": "NC",
        "postal_code": "28025",
        "token": "client-provided-token-34",
    },
    {
        "street": "14421 Cloudview Way",
        "city": "Haslet",
        "state": "TX",
        "postal_code": "76052",
        "token": "client-provided-token-35",
    },
    {
        "street": "15513 Gray Catbird",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78253",
        "token": "client-provided-token-36",
    },
    {
        "street": "459 Fernwood Cir",
        "city": "Statham",
        "state": "GA",
        "postal_code": "30666",
        "token": "client-provided-token-37",
    },
    {
        "street": "2105 Broad Plum Ln",
        "city": "Indian Trail",
        "state": "NC",
        "postal_code": "28079",
        "token": "client-provided-token-38",
    },
    {
        "street": "23803 N Desert Agave St",
        "city": "Florence",
        "state": "AZ",
        "postal_code": "85132",
        "token": "client-provided-token-39",
    },
    {
        "street": "24562 Lorenzo Glaze Trl",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77493",
        "token": "client-provided-token-40",
    },
    {
        "street": "4111 Magliana Ln",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77449",
        "token": "client-provided-token-41",
    },
    {
        "street": "1736 S 236th Dr",
        "city": "Buckeye",
        "state": "AZ",
        "postal_code": "85326",
        "token": "client-provided-token-42",
    },
    {
        "street": "5218 Eagleton Dr",
        "city": "Rosenberg",
        "state": "TX",
        "postal_code": "77469",
        "token": "client-provided-token-43",
    },
    {
        "street": "392 Harmony Grove Rd",
        "city": "Lilburn",
        "state": "GA",
        "postal_code": "30047",
        "token": "client-provided-token-44",
    },
    {
        "street": "4142 Woodland Park Dr SW",
        "city": "Atlanta",
        "state": "GA",
        "postal_code": "30331",
        "token": "client-provided-token-45",
    },
    {
        "street": "20426 Drakewood Dr",
        "city": "Katy",
        "state": "TX",
        "postal_code": "77449",
        "token": "client-provided-token-46",
    },
    {
        "street": "3110 Persing Ct",
        "city": "Monroe",
        "state": "NC",
        "postal_code": "28110",
        "token": "client-provided-token-47",
    },
    {
        "street": "1020 E Denim Trl",
        "city": "San Tan Valley",
        "state": "AZ",
        "postal_code": "85143",
        "token": "client-provided-token-48",
    },
    {
        "street": "5027 Cambridge Ln",
        "city": "Villa Rica",
        "state": "GA",
        "postal_code": "30180",
        "token": "client-provided-token-49",
    },
    {
        "street": "8902 Arbor Creek Dr",
        "city": "Charlotte",
        "state": "NC",
        "postal_code": "28269",
        "token": "client-provided-token-50",
    },
    {
        "street": "145 Road 5102 F",
        "city": "Cleveland",
        "state": "TX",
        "postal_code": "77327",
        "token": "client-provided-token-51",
    },
    {
        "street": "139 Rosedale Cir",
        "city": "Winston Salem",
        "state": "NC",
        "postal_code": "27106",
        "token": "client-provided-token-52",
    },
    {
        "street": "3743 Solanum Dr",
        "city": "Conroe",
        "state": "TX",
        "postal_code": "77301",
        "token": "client-provided-token-53",
    },
    {
        "street": "11959 W Hopi St",
        "city": "Avondale",
        "state": "AZ",
        "postal_code": "85323",
        "token": "client-provided-token-54",
    },
    {
        "street": "14765 Country Club Dr",
        "city": "Beaumont",
        "state": "TX",
        "postal_code": "77705",
        "token": "client-provided-token-55",
    },
    {
        "street": "13003 Rosemary Cv",
        "city": "Saint Hedwig",
        "state": "TX",
        "postal_code": "78109",
        "token": "client-provided-token-56",
    },
    {
        "street": "1169 Crestview Dr",
        "city": "Hutchins",
        "state": "TX",
        "postal_code": "75141",
        "token": "client-provided-token-57",
    },
    {
        "street": "6763 Arid Way",
        "city": "San Antonio",
        "state": "TX",
        "postal_code": "78252",
        "token": "client-provided-token-58",
    },
    {
        "street": "90 Cedar Creek Dr",
        "city": "Covington",
        "state": "GA",
        "postal_code": "30014",
        "token": "client-provided-token-59",
    },
]

# get rent estimates for the addresses
ordered_tokens = [address["token"] for address in addresses]
for result, expected_token in zip(
    client.data.rent_estimates.fetch(addresses=addresses), ordered_tokens
):  # type: (rent_estimates_response.Result, Optional[str])
    assert result.token == expected_token

    print("Token:", result.token)
    if result.rent_estimate:
        print("Estimated Rent Low:", result.rent_estimate.estimated_rent_low)
        print("Estimated Rent:", result.rent_estimate.estimated_rent)
        print("Estimated Rent High:", result.rent_estimate.estimated_rent_high)
    else:
        print("No rent estimate available for this address")
